package ${package}.customEvents;

public class EXTRASEventsHandler {
    
// A map to store copies of each player's inventory
private Map<EntityPlayer, ItemStack[]> playerInventories = new HashMap<>();

@SubscribeEvent
public void onPlayerTick(TickEvent.PlayerTickEvent event) {
    // Get the player from the event
    EntityPlayer player = event.player;

    // Get the current and previous inventories
    int totalSlots = player.inventory.getSizeInventory() + 4; // 4 armor slots
    ItemStack[] currentInventory = new ItemStack[totalSlots];
    for (int i = 0; i < totalSlots; i++) {
        if (i < player.inventory.mainInventory.size()) {
            currentInventory[i] = new Object() {
                public ItemStack getItemStack(int sltid, Entity entity) {
                    AtomicReference<ItemStack> _retval = new AtomicReference<>(ItemStack.EMPTY);
                    entity.getCapability(ForgeCapabilities.ITEM_HANDLER, null).ifPresent(capability -> {
                        _retval.set(capability.getStackInSlot(sltid).copy());
                    });
                    return _retval.get();
                }
            }.getItemStack(i, player);
        } else {
            EquipmentSlotType slotType;
            switch (i - player.inventory.mainInventory.size()) {
                case 0:
                    slotType = EquipmentSlotType.FEET;
                    break;
                case 1:
                    slotType = EquipmentSlotType.LEGS;
                    break;
                case 2:
                    slotType = EquipmentSlotType.CHEST;
                    break;
                default:
                    slotType = EquipmentSlotType.HEAD;
            }
            currentInventory[i] = (player instanceof LivingEntity) ? ((LivingEntity)player).getItemBySlot(slotType) : ItemStack.EMPTY;
        }
    }

    ItemStack[] previousInventory = playerInventories.get(player);

    // If the player's inventory is not in the map, add it
    if (previousInventory == null) {
        previousInventory = currentInventory.clone();
        playerInventories.put(player, previousInventory);
    }

    // Check each slot in the player's inventory
    for (int i = 0; i < totalSlots; i++) {
        ItemStack currentItem = currentInventory[i];
        ItemStack previousItem = previousInventory[i];

        // If the items are not equal, fire your event
        if (!ItemStack.areItemStacksEqual(currentItem, previousItem)) {
            boolean isArmor = i >= player.inventory.mainInventory.size();
            Object actionType;
            if (previousItem.getItem() == Blocks.AIR.asItem()) {
                actionType = 11;
            } else if (currentItem.getItem() == Blocks.AIR.asItem()) {
                actionType = 10;
            } else {
                actionType = 12;
            }
            EXTRASEvents.InventoryInteraction inventoryEvent = new EXTRASEvents.InventoryInteraction(player, i, isArmor, currentItem, actionType);
            MinecraftForge.EVENT_BUS.post(inventoryEvent);

            if (inventoryEvent.isCanceled()) {
                // The event was canceled, handle it here
                break;
            } else {
                // Update the item in the copied inventory
                previousInventory[i] = currentItem.isEmpty() ? ItemStack.EMPTY : currentItem.copy();
            }
        }
    }
}


}